@@ -79,7 +79,7 @@ struct _PTPUSBBulkContainer {
 			uint32_t param4;
 			uint32_t param5;
 		} params;
-		unsigned char data[PTP_USB_BULK_PAYLOAD_LEN];
+		////unsigned char data[PTP_USB_BULK_PAYLOAD_LEN];
 	} payload;
 };
 typedef struct _PTPUSBBulkContainer PTPUSBBulkContainer;
